aind\_behavior\_curriculum.task.Task
====================================

.. currentmodule:: aind_behavior_curriculum.task

.. autoclass:: Task
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Task.__init__
      ~Task.construct
      ~Task.copy
      ~Task.dict
      ~Task.from_orm
      ~Task.json
      ~Task.model_construct
      ~Task.model_copy
      ~Task.model_dump
      ~Task.model_dump_json
      ~Task.model_json_schema
      ~Task.model_parametrized_name
      ~Task.model_post_init
      ~Task.model_rebuild
      ~Task.model_validate
      ~Task.model_validate_json
      ~Task.model_validate_strings
      ~Task.parse_file
      ~Task.parse_obj
      ~Task.parse_raw
      ~Task.schema
      ~Task.schema_json
      ~Task.update_forward_refs
      ~Task.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Task.model_computed_fields
      ~Task.model_config
      ~Task.model_extra
      ~Task.model_fields
      ~Task.model_fields_set
      ~Task.name
      ~Task.description
      ~Task.task_parameters
      ~Task.version
      ~Task.stage_name
   
   